@@ -2,6 +2,8 @@
  * defrag.c - the Linux file system degragmenter.
  * $Id: defrag.c,v 1.6 1994/07/12 13:31:42 linux Exp $
  *
+ * changes are Copyleft  (C) 1997 Anthony Tong (antoine@eci.com)
+ *
  * Copyright (C) 1992, 1993 Stephen Tweedie (sct@dcs.ed.ac.uk)
  *
  * Copyright (C) 1992 Remy Card (card@masi.ibp.fr) 
@@ -32,7 +34,7 @@
 int debug = 0;
 #endif
 
-char * RCSID = "$Id: defrag.c,v 1.6 1994/07/12 13:31:42 linux Exp $";
+char * RCSID = "$Id: defrag.c,v 0.61 1997/01/28 13:29:09 linux Exp $";
 
 int die_on_io_error = 1;
 int io_errors = 0;
@@ -418,8 +420,9 @@ void read_fixed_zones (void)
 	int tmp = badblocks;
 	
 	int i;
-	for (i=1; i < EXT2_FIRST_INO; i++) {        
-	    if ((i == EXT2_ROOT_INO) ||  /* Allow optimization of root inode */
+	for (i=1; i < FIRST_USER_INODE; i++) {        
+	    if ((i == EXT2_ROOT_INO) ||  /* Allow optimization of root
+inode */
 		(i == bad_block_inode))  /* Done with them already */
 		continue;
 	    if (!inode_in_use (i))
