@@ -6,6 +6,10 @@
  * Alexey Vovenko (vovenko@ixwin.ihep.su)
  */
 
+/* added #define; FIRST_USER_INODE replaces EXT2_FIRST_INO
+ * Anthony Tong (antoine@eci.com)
+ */
+
  /* Known bugs:
   * 1. Picture option uses ncurses and requires a terminfo description
   *    from the ncurses package. Default terminfo files (from SLS at least)
@@ -20,6 +24,10 @@
 #include <linux/ext2_fs.h>
 #include "display.h"
 
+#define FIRST_USER_INODE ((s.s_rev_level == EXT2_GOOD_OLD_REV) ? \
+				EXT2_GOOD_OLD_FIRST_INO : \
+				s.s_first_ino)
+
 #ifndef TRUE
   #define FALSE 0 
   #define TRUE  1
@@ -508,7 +516,7 @@ void report_fragm(void) {
          avr_dist_file=0,
          avr_fr_size_file=0;
          
-   for (inode_no=EXT2_FIRST_INO; inode_no <= s.s_inodes_count; inode_no++) {
+   for (inode_no=FIRST_USER_INODE; inode_no <= s.s_inodes_count; inode_no++) {
       load_inode(&n,inode_no);
       if (n.i_dtime != 0 || n.i_ctime==0) { /* FIXME: is it a free inode? */
          if (inode_is_busy(inode_no))
@@ -603,7 +611,7 @@ void report_group_fill(void) {
       for (inode_no=gr_no*s.s_inodes_per_group+1; 
            inode_no <= s.s_inodes_per_group*(gr_no+1); 
            inode_no++) {
-         if (inode_no < EXT2_FIRST_INO && inode_no!=EXT2_ROOT_INO) 
+         if (inode_no < FIRST_USER_INODE && inode_no!=EXT2_ROOT_INO) 
              continue;  
             
          load_inode(&n,inode_no);
